pub struct File { /* private fields */ }Expand description
A FileHandle implementation for remote files, with automatic caching.
A file’s bytes come from one of:
- the object store, as the whole object (
File::open); - the object store, as a byte range of a bundle object (
File::bundled); - memory, for files that are logically empty or whose bundle has not been synced yet.
Implementations